==> cordova-sqlite-react-1.1.6.tgz: package/@types/commonType.ts <==
import { SQLitePlugin } from './SQLitePlugin';


export interface returnCommonPropsPromise {
  status: boolean;
  msg: string;
}

export interface returnGetDataSqliteT extends Partial<Pick<returnCommonPropsPromise, 'msg'>>, Omit<returnCommonPropsPromise, 'msg'>{
  value?:{}[] | [];
}

export interface SelectWhere{
  where?:object;
  sql?: string;
}

export interface DeleteWhere extends Omit<SelectWhere, 'sql'>{
  whereArrKey?: {key?: string[], value?: (string | number)[]};
  condition?: 'AND' | 'OR';
}

export interface UpdateWhere extends Omit<DeleteWhere, 'whereArrKey'>{
  stringWhere?:string;
}

export interface setDataSqliteOptions {
  isCreateDate?: boolean | undefined;
  rewriteTable?: boolean | undefined;
}

export type commonFunctionSqliteT = (connect:SQLitePlugin, nameTable:string) => Promise<returnCommonPropsPromise> 
export type getDataSqliteT = (connect:SQLitePlugin, nameTable:string, {where, sql}:SelectWhere) => Promise<returnGetDataSqliteT> 
export type setDataSqliteT = (connect:SQLitePlugin, nameTable:string, payload: object, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
export type updateDataSqliteT = (connect:SQLitePlugin, nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteDataSqliteT = (connect:SQLitePlugin, nameTable:string, {where, whereArrKey, condition}:DeleteWhere) => Promise<returnCommonPropsPromise> 

/*#############----------<{ Class Sqlite }>-----------########## */
export type commonMethodSqliteT = (nameTable:string) => Promise<returnCommonPropsPromise> 
export type getDataT = (nameTable:string, {where, sql}:SelectWhere) => Promise<returnGetDataSqliteT> 
export type setDataT = (nameTable:string, payload: object, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
export type updateDataT = (nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteDataT = (nameTable:string, {where, whereArrKey, condition}:DeleteWhere) => Promise<returnCommonPropsPromise> 


/*#############----------<{ Class SLStore }>-----------########## */

// export type commonMethodSqliteT = (nameTable:string) => Promise<returnCommonPropsPromise> 
export type getItemT = (key:string) => Promise<returnGetDataSqliteT> 
export type setItemT = (key:string, value: any, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
// export type updateDataT = (nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
// export type remoteDataT = (nameTable:string, {where, whereArrKey, condition}:DeleteWhere) => Promise<returnCommonPropsPromise>

==> cordova-sqlite-react-1.1.7.tgz: package/@types/commonType.ts <==
import { SQLitePlugin } from './SQLitePlugin';


export interface returnCommonPropsPromise {
  status: boolean;
  msg: string;
}

export interface returnGetDataSqliteT extends Partial<Pick<returnCommonPropsPromise, 'msg'>>, Omit<returnCommonPropsPromise, 'msg'>{
  value?:{}[] | [];
}

export interface SelectWhere{
  where?:object;
  sql?: string;
}

export interface DeleteWhere extends Omit<SelectWhere, 'sql'>{
  whereKey?: {[key:string]: string[]};
  ignoreWhere?: {[key:string]: string[]};
  condition?: 'AND' | 'OR';
  stringWhere?:string;
}

export interface UpdateWhere extends Omit<DeleteWhere, 'whereKey' | 'ignoreWhere'>{ }

export interface setDataSqliteOptions {
  isCreateDate?: boolean | undefined;
  rewriteTable?: boolean | undefined;
}


export type commonFunctionSqliteT = (connect:SQLitePlugin, nameTable:string) => Promise<returnCommonPropsPromise> 
export type getDataSqliteT = (connect:SQLitePlugin, nameTable:string, {where, sql}:SelectWhere) => Promise<returnGetDataSqliteT> 
export type setDataSqliteT = (connect:SQLitePlugin, nameTable:string, payload: object, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
export type updateDataSqliteT = (connect:SQLitePlugin, nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteDataSqliteT = (connect:SQLitePlugin, nameTable:string, param:DeleteWhere) => Promise<returnCommonPropsPromise> 

/*#############----------<{ Class Sqlite }>-----------########## */
export type commonMethodSqliteT = (nameTable:string) => Promise<returnCommonPropsPromise> 
export type getDataT = (nameTable:string, {where, sql}:SelectWhere) => Promise<returnGetDataSqliteT> 
export type setDataT = (nameTable:string, payload: object, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
export type updateDataT = (nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
export type remoteDataT = (nameTable:string, param:DeleteWhere) => Promise<returnCommonPropsPromise> 


/*#############----------<{ Class SLStore }>-----------########## */

// export type commonMethodSqliteT = (nameTable:string) => Promise<returnCommonPropsPromise> 
export type getItemT = (key:string) => Promise<returnGetDataSqliteT> 
export type setItemT = (key:string, value: any, options?:setDataSqliteOptions) => Promise<returnCommonPropsPromise> 
// export type updateDataT = (nameTable:string, payload: object, {where, condition, stringWhere}: UpdateWhere) => Promise<returnCommonPropsPromise> 
// export type remoteItemT = (nameTable:string, param:DeleteWhere) => Promise<returnCommonPropsPromise>
